@@ -14,7 +14,7 @@ from ..drivers.browsers.local_browsers import LocalBrowsers
 
 
 from ..conf.app import ports_conf     # use for local mobile tests
-localhost_url = 'http://localhost:%s' % ports_conf.port    # Set the url of localhost
+localhost_url = 'http://localhost:%s' % ports_conf.port    # Set the url of localhost, removed /wd/host after Appium2
 
 
 class DriverFactory(RemoteOptions, LocalBrowsers):
@@ -194,12 +194,14 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
                 desired_capabilities['appActivity'] = app_activity
                 desired_capabilities['noReset'] = True if no_reset_flag.lower() == 'true' else False
                 desired_capabilities['automationName'] = "uiautomator2"
-                capabilities_options = UiAutomator2Options().load_capabilities(desired_capabilities)
+                # capabilities_options = UiAutomator2Options().load_capabilities(desired_capabilities)
                 if device_flag.lower() == 'y':
-                    mobile_driver = mobile_webdriver.Remote(localhost_url, capabilities_options)
+                    # mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
+                    mobile_driver = mobile_webdriver.Remote(localhost_url, options=UiAutomator2Options().load_capabilities(desired_capabilities))
                 else:
                     desired_capabilities['app'] = os.path.join(app_path, app_name)
-                    mobile_driver = mobile_webdriver.Remote(localhost_url, capabilities_options)
+                    # mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
+                    mobile_driver = mobile_webdriver.Remote(localhost_url, options=UiAutomator2Options().load_capabilities(desired_capabilities))
 
             except Exception as exception:
                 self.print_exception(exception, remote_flag)
@@ -224,13 +226,14 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
                 desired_capabilities['app'] = os.path.join(app_path, app_name)
                 desired_capabilities['bundleId'] = app_package
                 desired_capabilities['noReset'] = no_reset_flag
+                desired_capabilities['automationName'] = "uiautomator2"
                 if ud_id is not None:
                     desired_capabilities['udid'] = ud_id
                     desired_capabilities['xcodeOrgId'] = org_id
                     desired_capabilities['xcodeSigningId'] = signing_id
 
-                mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
-
+                # mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
+                mobile_driver = mobile_webdriver.Remote(localhost_url, options=UiAutomator2Options().load_capabilities(desired_capabilities))
             except Exception as exception:
                 self.print_exception(exception, remote_flag)
 
