@@ -7,6 +7,7 @@ from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.support.select import Select
+from selenium.webdriver.common.by import By
 import unittest, time, logging, os, inspect
 from ..utils.general.Base_Logging import Base_Logging
 from ..remoteTest.BrowserStack_Library import BrowserStack_Library
@@ -502,7 +503,8 @@ class Base_Page(Borg, unittest.TestCase):
         if name is not None:
             self.driver.switch_to.frame(name)
         elif index is not None:
-            self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
+            # self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
+            self.driver.switch_to.frame(self.driver.find_elements(By.TAG_NAME, "iframe")[index])
         elif frame_id is not None:  # add by myself
             self.driver.switch_to.frame(frame_id)
         # else:
@@ -516,7 +518,8 @@ class Base_Page(Borg, unittest.TestCase):
         if name is not None:
             self.driver.switch_to.frame(name)
         elif index is not None:
-            self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
+            # self.driver.switch_to.frame(self.driver.find_elements_by_tag_name("iframe")[index])
+            self.driver.switch_to.frame(self.driver.find_elements(By.TAG_NAME, "iframe")[index])
         elif frame_id is not None:
             self.driver.switch_to.frame(frame_id)
         elif element is not None:
@@ -664,7 +667,8 @@ class Base_Page(Borg, unittest.TestCase):
         "Return a list of DOM elements that with provided tag"
         dom_elements = []
         try:
-            dom_elements = self.driver.find_elements_by_tag_name(tag)
+            # dom_elements = self.driver.find_elements_by_tag_name(tag)
+            dom_elements = self.driver.find_elements(By.TAG_NAME, tag)
             if self.highlight_flag is True:
                 self.highlight_elements(dom_elements)
         except Exception as e:
@@ -680,7 +684,8 @@ class Base_Page(Borg, unittest.TestCase):
         "Provide an element, return a list of DOM elements that with provided tag under that element"
         dom_elements = []
         try:
-            dom_elements = element.find_elements_by_tag_name(tag)
+            # dom_elements = element.find_elements_by_tag_name(tag)
+            dom_elements = element.find_elements(By.TAG_NAME, tag)
             if self.highlight_flag is True:
                 self.highlight_elements(dom_elements)
         except Exception as e:
@@ -936,8 +941,9 @@ class Base_Page(Borg, unittest.TestCase):
         result_flag = False
         try:
             dropdown = self.get_element(locator)
-            li = dropdown.find_elements_by_tag_name('option')
-            for option in dropdown.find_elements_by_tag_name('option'):
+            # li = dropdown.find_elements_by_tag_name('option')
+            # for option in dropdown.find_elements_by_tag_name('option'):
+            for option in dropdown.find_elements(By.TAG_NAME, 'option'):
                 if option.text == option_text:
                     option.click()
                     result_flag = True
@@ -952,8 +958,9 @@ class Base_Page(Borg, unittest.TestCase):
         result_flag = False
         try:
             dropdown = self.get_element(locator)
-            li = dropdown.find_elements_by_tag_name('option')
-            for option in dropdown.find_elements_by_tag_name('option'):
+            # li = dropdown.find_elements_by_tag_name('option')
+            # for option in dropdown.find_elements_by_tag_name('option'):
+            for option in dropdown.find_elements(By.TAG_NAME, 'option'):
                 text = self.get_element_attribute_value(option, 'textContent')
                 if option.text == option_text:
                     option.click()
@@ -969,7 +976,8 @@ class Base_Page(Borg, unittest.TestCase):
         result_flag = False
         try:
             dropdown = self.get_element(locator)
-            for option in dropdown.find_elements_by_tag_name('option'):
+            # for option in dropdown.find_elements_by_tag_name('option'):
+            for option in dropdown.find_elements(By.TAG_NAME, 'option'):
                 if self.get_element_attribute_value(option, 'value') == value:
                     option.click()
                     result_flag = True
